@@ -45,6 +45,9 @@ class Proxy:
 
             self.original_method()
 
+            from django.db import connections
+            connections.close_all()
+
             if self.callback:
                 self.callback()
 
