@@ -17,6 +17,12 @@ class Proxy:
 
         result = self.original_method(*args, **kwargs)
 
+        from django.db import connections
+        try:
+            connections.close_all()
+        except:
+            pass
+
         if self.callback:
             if self.callback.__code__.co_argcount == 1:
                 self.callback(result)
